=======================
zinnia-wysiwyg-markitup
=======================

Zinnia-wysiwyg-markitup is a package allowing you to edit your entries
with `MarkItUp`_.

Installation
============

* Install the package on your system: ::

  $ pip install zinnia-wysiwyg-markitup

* Register the ``'zinnia_markitup'`` in your ``INSTALLED_APPS`` after the
  ``'zinnia'`` application.

You are done !

.. _MarkItUp: http://markitup.jaysalvat.com/home/
